LoopParameters class

Constructors

LoopParameters({bool split = true, bool uvSmooth = false, bool preserveEdges = false, bool flatOnly = false, int? maxTriangles, double weight = 1})
LoopParameters.fromJson(Map<String, dynamic> json)

Properties

flatOnly ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxTriangles ↔ int
getter/setter pair
preserveEdges ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
split ↔ bool
getter/setter pair
uvSmooth ↔ bool
getter/setter pair
weight ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited