Vertex class

Constructors

Vertex(Vector3 position, Vector3? uv, Vector3? normal, Vector4? tangent, Color? color)

Properties

collapseCost ↔ double
getter/setter pair
collapseNeighbor ↔ Vertex?
getter/setter pair
color ↔ Color?
getter/setter pair
costCount ↔ int
getter/setter pair
faces → List<Triangle>
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
minCost ↔ double
getter/setter pair
neighbors → List<Vertex>
final
normal ↔ Vector3?
getter/setter pair
position → Vector3
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tangent ↔ Vector4?
getter/setter pair
totalCost ↔ double
getter/setter pair
uv ↔ Vector3?
getter/setter pair

Methods

addUniqueNeighbor(Vertex? vertex) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIfNonNeighbor(Vertex n) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override