TessellateModifier class

Constructors

TessellateModifier([double maxEdgeLength = 0.1, int maxIterations = 6])

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxEdgeLength ↔ double
getter/setter pair
maxIterations ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

modify(BufferGeometry geometry) → BufferGeometry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited